@@ -4,7 +4,7 @@ test_that("Returns the inverse hyperbolic tangent (arctanh) of each values in a
 
   skip_on_cran()
   skip_if_not(check_whitebox_binary())
-  dem <- system.file("extdata", "DEM.tif", package = "whitebox")
+  dem <- sample_dem_data(); skip_if(dem == "")
   ret <- wbt_artanh(input = dem, output = "output.tif")
   expect_match(ret, "Elapsed Time")
 
