@@ -4,7 +4,7 @@ test_that("Changes the sign of values in a raster or the 0-1 values of a Boolean
 
   skip_on_cran()
   skip_if_not(check_whitebox_binary())
-  dem <- system.file("extdata", "DEM.tif", package = "whitebox")
+  dem <- sample_dem_data(); skip_if(dem == "")
   ret <- wbt_negate(input = dem, output = "output.tif")
   expect_match(ret, "Elapsed Time")
 
